@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,15 +10,22 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KUrlRequester>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace MailCommon;
+namespace
+{
+static const char myFilterActionMissingSoundUrlDialogGroupName[] = "FilterActionMissingSoundUrlDialog";
+}
 
 FilterActionMissingSoundUrlDialog::FilterActionMissingSoundUrlDialog(const QString &filtername, const QString &argStr, QWidget *parent)
     : QDialog(parent)
+    , mUrlWidget(new KUrlRequester(this))
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select sound"));
@@ -37,7 +44,6 @@ FilterActionMissingSoundUrlDialog::FilterActionMissingSoundUrlDialog(const QStri
              filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
-    mUrlWidget = new KUrlRequester(this);
     mUrlWidget->setObjectName(QStringLiteral("urlwidget"));
     mainLayout->addWidget(mUrlWidget);
 
@@ -65,16 +71,16 @@ QString FilterActionMissingSoundUrlDialog::soundUrl() const
 
 void FilterActionMissingSoundUrlDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingSoundUrlDialog");
-
-    const QSize size = group.readEntry("Size", QSize(500, 300));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(500, 300));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingSoundUrlDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void FilterActionMissingSoundUrlDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingSoundUrlDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingSoundUrlDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
