@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONSENDFAKEDISPOSITION_H
-#define MAILCOMMON_FILTERACTIONSENDFAKEDISPOSITION_H
+#pragma once
 
 #include "filteractionwithstringlist.h"
 
@@ -34,5 +33,3 @@ public:
     Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
 };
 }
-
-#endif
