@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONSETSTATUS_H
-#define MAILCOMMON_FILTERACTIONSETSTATUS_H
+#pragma once
 
 #include "filteractionstatus.h"
 namespace MailCommon
@@ -30,5 +29,3 @@ public:
     Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
 };
 }
-
-#endif
