@@ -1,19 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "filterconverttosievepurposemenuwidget.h"
 #include <KPIMTextEdit/PlainTextEditor>
-
+using namespace MailCommon;
 FilterconverttosievePurposeMenuWidget::FilterconverttosievePurposeMenuWidget(QWidget *parentWidget, QObject *parent)
     : PimCommon::PurposeMenuWidget(parentWidget, parent)
 {
 }
 
-FilterconverttosievePurposeMenuWidget::~FilterconverttosievePurposeMenuWidget()
-{
-}
+FilterconverttosievePurposeMenuWidget::~FilterconverttosievePurposeMenuWidget() = default;
 
 QByteArray FilterconverttosievePurposeMenuWidget::text()
 {
