@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -37,10 +37,10 @@ public Q_SLOTS:
 private:
     void writeConfig();
     void readConfig();
-    QListWidget *filtersListWidget = nullptr;
+    QListWidget *const filtersListWidget;
     QVector<MailFilter *> originalFilters;
-    QPushButton *selectAllButton = nullptr;
-    QPushButton *unselectAllButton = nullptr;
+    QPushButton *const selectAllButton;
+    QPushButton *const unselectAllButton;
     QPushButton *mOkButton = nullptr;
 };
 }
