@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,12 +10,17 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace MailCommon;
-
+namespace
+{
+static const char myInvalidFilterDialogName[] = "InvalidFilterDialog";
+}
 InvalidFilterDialog::InvalidFilterDialog(QWidget *parent)
     : QDialog(parent)
     , mInvalidFilterWidget(new InvalidFilterWidget(this))
@@ -60,17 +65,18 @@ void InvalidFilterDialog::setInvalidFilters(const QVector<InvalidFilterInfo> &ls
     mInvalidFilterWidget->setInvalidFilters(lst);
 }
 
-void InvalidFilterDialog::writeConfig()
-{
-    KConfigGroup group(KSharedConfig::openStateConfig(), "InvalidFilterDialog");
-    group.writeEntry("Size", size());
-}
-
 void InvalidFilterDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "InvalidFilterDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(400, 500));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(400, 500));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myInvalidFilterDialogName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
+}
+
+void InvalidFilterDialog::writeConfig()
+{
+    KConfigGroup group(KSharedConfig::openStateConfig(), myInvalidFilterDialogName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
