@@ -55,12 +55,6 @@ public:
     void clear();
 
 Q_SIGNALS:
-    /**
-     * This signal is emitted when the user clicked
-     * the Play button.
-     */
-    void testPressed();
-
     /**
      * This signal is emitted when the user
      * enters a new URL.
