@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,19 +14,22 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include <AkonadiCore/AgentInstance>
-#include <AkonadiCore/AgentManager>
-
-#include <KMime/KMimeMessage>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentManager>
 
 #include <KConfigGroup>
+#include <KWindowConfig>
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QListWidget>
+#include <QWindow>
 
 using namespace MailCommon;
-
+namespace
+{
+static const char myAccountConfigOrderDialogName[] = "AccountConfigOrderDialog";
+}
 struct InstanceStruct {
     QString name;
     QIcon icon;
@@ -65,7 +68,7 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(MailCommon::MailCommonSetting
     mainLayout->addWidget(buttonBox);
 
     auto vbox = new QVBoxLayout;
-    vbox->setContentsMargins(0, 0, 0, 0);
+    vbox->setContentsMargins({});
     page->setLayout(vbox);
 
     d->mEnableAccountOrder = new QCheckBox(i18n("Use custom order"), this);
@@ -81,7 +84,7 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(MailCommon::MailCommonSetting
 
     auto upDownBox = new QWidget(page);
     auto upDownBoxVBoxLayout = new QVBoxLayout(upDownBox);
-    upDownBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
+    upDownBoxVBoxLayout->setContentsMargins({});
     d->mUpButton = new QPushButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(d->mUpButton);
     d->mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
@@ -116,7 +119,6 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(MailCommon::MailCommonSetting
 AccountConfigOrderDialog::~AccountConfigOrderDialog()
 {
     writeConfig();
-    delete d;
 }
 
 void AccountConfigOrderDialog::slotEnableAccountOrder(bool state)
@@ -237,16 +239,16 @@ void AccountConfigOrderDialog::slotOk()
 
 void AccountConfigOrderDialog::readConfig()
 {
-    KConfigGroup accountConfigDialog(d->mSettings->config(), "AccountConfigOrderDialog");
-    const QSize size = accountConfigDialog.readEntry("Size", QSize(600, 400));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(500, 150));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myAccountConfigOrderDialogName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void AccountConfigOrderDialog::writeConfig()
 {
-    KConfigGroup accountConfigDialog(d->mSettings->config(), "AccountConfigOrderDialog");
-    accountConfigDialog.writeEntry("Size", size());
-    accountConfigDialog.sync();
+    KConfigGroup group(KSharedConfig::openStateConfig(), myAccountConfigOrderDialogName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
