@@ -2,7 +2,7 @@
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
   SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,6 +14,7 @@
 #include <KMessageBox>
 #include <KSharedConfig>
 #include <QDataStream>
+#include <QIODevice>
 #include <QMimeData>
 #include <QStringList>
 
@@ -41,10 +42,10 @@ public:
 
     void appendChild(SnippetItem *child);
     void removeChild(SnippetItem *child);
-    SnippetItem *child(int row) const;
+    Q_REQUIRED_RESULT SnippetItem *child(int row) const;
     Q_REQUIRED_RESULT int childCount() const;
     Q_REQUIRED_RESULT int row() const;
-    SnippetItem *parent() const;
+    Q_REQUIRED_RESULT SnippetItem *parent() const;
 
     Q_REQUIRED_RESULT QString subject() const;
     void setSubject(const QString &subject);
@@ -296,7 +297,7 @@ bool SnippetsModel::setData(const QModelIndex &index, const QVariant &value, int
 QVariant SnippetsModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
-        return QVariant();
+        return {};
     }
 
     auto item = static_cast<SnippetItem *>(index.internalPointer());
@@ -326,7 +327,7 @@ QVariant SnippetsModel::data(const QModelIndex &index, int role) const
         return item->attachment();
     }
 
-    return QVariant();
+    return {};
 }
 
 Qt::ItemFlags SnippetsModel::flags(const QModelIndex &index) const
@@ -346,7 +347,7 @@ Qt::ItemFlags SnippetsModel::flags(const QModelIndex &index) const
 QModelIndex SnippetsModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (!hasIndex(row, column, parent)) {
-        return QModelIndex();
+        return {};
     }
 
     SnippetItem *parentItem = nullptr;
@@ -361,21 +362,21 @@ QModelIndex SnippetsModel::index(int row, int column, const QModelIndex &parent)
     if (childItem) {
         return createIndex(row, column, childItem);
     } else {
-        return QModelIndex();
+        return {};
     }
 }
 
 QModelIndex SnippetsModel::parent(const QModelIndex &index) const
 {
     if (!index.isValid()) {
-        return QModelIndex();
+        return {};
     }
 
     auto childItem = static_cast<SnippetItem *>(index.internalPointer());
     SnippetItem *parentItem = childItem->parent();
 
     if (parentItem == mRootItem) {
-        return QModelIndex();
+        return {};
     }
 
     return createIndex(parentItem->row(), 0, parentItem);
@@ -520,7 +521,12 @@ bool SnippetsModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
             Q_EMIT dndDone();
             return true;
         } else {
-            if (KMessageBox::Yes == KMessageBox::questionYesNo(nullptr, i18n("Do you want to update snippet?"), i18n("Update snippet"))) {
+            if (KMessageBox::ButtonCode::PrimaryAction
+                == KMessageBox::questionTwoActions(nullptr,
+                                                   i18n("Do you want to update snippet?"),
+                                                   i18n("Update snippet"),
+                                                   KGuiItem(i18n("Update")),
+                                                   KStandardGuiItem::cancel())) {
                 item->setText(text);
                 item->setSubject(subject);
                 item->setTo(to);
@@ -544,7 +550,12 @@ bool SnippetsModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         if (item->isGroup()) {
             Q_EMIT addNewDndSnippset(encodedData);
         } else {
-            if (KMessageBox::Yes == KMessageBox::questionYesNo(nullptr, i18n("Do you want to update snippet?"), i18n("Update snippet"))) {
+            if (KMessageBox::ButtonCode::PrimaryAction
+                == KMessageBox::questionTwoActions(nullptr,
+                                                   i18n("Do you want to update snippet?"),
+                                                   i18n("Update snippet"),
+                                                   KGuiItem(i18n("Update")),
+                                                   KStandardGuiItem::cancel())) {
                 item->setText(encodedData);
             }
         }
