@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,6 +17,8 @@
 #include <KLocalizedString>
 #include <KXMLGUIClient>
 
+#include <QActionGroup>
+#include <QApplication>
 #include <QFontDatabase>
 #include <QMimeData>
 #include <QMouseEvent>
@@ -33,6 +35,7 @@ public:
     QAction *listMode = nullptr;
     QAction *iconMode = nullptr;
     MailCommonSettings *settings = nullptr;
+    Akonadi::CollectionStatisticsDelegate *delegate = nullptr;
 };
 
 FavoriteCollectionWidget::FavoriteCollectionWidget(MailCommon::MailCommonSettings *settings, KXMLGUIClient *xmlGuiClient, QWidget *parent)
@@ -42,20 +45,28 @@ FavoriteCollectionWidget::FavoriteCollectionWidget(MailCommon::MailCommonSetting
     d->settings = settings;
     setFocusPolicy(Qt::NoFocus);
 
-    auto delegate = new Akonadi::CollectionStatisticsDelegate(this);
-    delegate->setProgressAnimationEnabled(true);
+    d->delegate = new Akonadi::CollectionStatisticsDelegate(this);
+    d->delegate->setProgressAnimationEnabled(true);
 
-    setItemDelegate(delegate);
+    setItemDelegate(d->delegate);
 
-    delegate->setUnreadCountShown(true);
+    d->delegate->setUnreadCountShown(true);
 
     readConfig();
 
     createMenu(xmlGuiClient->actionCollection());
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    connect(qApp, &QApplication::paletteChanged, this, &FavoriteCollectionWidget::updatePalette);
+#endif
 }
 
 FavoriteCollectionWidget::~FavoriteCollectionWidget() = default;
 
+void FavoriteCollectionWidget::updatePalette()
+{
+    d->delegate->updatePalette();
+}
+
 void FavoriteCollectionWidget::mousePressEvent(QMouseEvent *e)
 {
     const bool buttonPressedIsMiddle = (e->button() == Qt::MiddleButton);
@@ -306,3 +317,13 @@ void FavoriteCollectionWidget::startDrag(Qt::DropActions supportedActions)
     // skip EntityListView logic (we want to reorder favorites, not trigger moving/copying of actual folders)
     QListView::startDrag(supportedActions);
 }
+
+bool FavoriteCollectionWidget::event(QEvent *e)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (e->type() == QEvent::ApplicationPaletteChange) {
+        updatePalette();
+    }
+#endif
+    return Akonadi::EntityListView::event(e);
+}
